@@ -22,6 +22,7 @@ legitimate_motors = [
                     "AK80_6_V2",
                     "AK80_9_V1p1",
                     "AK80_9_V2",
+                    "AK70_10_V1p1",
                     "AK10_9_V1p1"
                     ]
 
@@ -101,6 +102,21 @@ AK80_9_V2_PARAMS = {
                     "AXIS_DIRECTION" : 1
                     }
 
+#  Working parameters for AK70-10 V1.1 firmware
+AK70_10_V1p1_params = {
+                      "P_MIN" :  -12.5,
+                      "P_MAX" :  12.5,
+                      "V_MIN" :  -50,
+                      "V_MAX" :  50,
+                      "KP_MIN" :  0,
+                      "KP_MAX" :  500,
+                      "KD_MIN" :  0,
+                      "KD_MAX" :  5,
+                      "T_MIN" :  -24.0,
+                      "T_MAX" :  24.0,
+                      "AXIS_DIRECTION" :  1
+                    }
+
 # Working parameters for AK10-9 V1.1 firmware
 AK10_9_V1p1_PARAMS = {
                 "P_MIN" : -12.5,
@@ -162,13 +178,7 @@ class CanMotorController():
     Class for creating a Mini-Cheetah Motor Controller over CAN. Uses SocketCAN driver for
     communication.
     """
-
-    # Declare Socket as Class Attribute instead of member attribute so that it can be used across
-    # multiple instances and check if the socket was declared earlier by an instance.
-
-    can_socket_declared = False
-    motor_socket = None
-
+    
     def __init__(self, can_socket='can0', motor_id=0x01, motor_type = 'AK80_6_V1p1',
                 socket_timeout=0.05):
         """
@@ -195,23 +205,21 @@ class CanMotorController():
             # and an error code. Hence data is 2 bytes longer.
             recvBytes = 16
             can_frame_fmt_recv = "=IB3x8s"
+        elif motor_type == 'AK70_10_V1p1':
+            self.motorParams = AK70_10_V1p1_params
 
         can_socket = (can_socket, )
         self.motor_id = motor_id
         # create a raw socket and bind it to the given CAN interface
-        if not CanMotorController.can_socket_declared:
-            try:
-                CanMotorController.motor_socket = socket.socket(socket.AF_CAN, socket.SOCK_RAW,
-                                                                socket.CAN_RAW)
-                CanMotorController.motor_socket.bind(can_socket)
-                CanMotorController.motor_socket.settimeout(socket_timeout)
-                print("Bound to: ", can_socket)
-                CanMotorController.can_socket_declared = True
-            except Exception as e:
-                print("Unable to Connect to Socket Specified: ", can_socket)
-                print("Error:", e)
-        elif CanMotorController.can_socket_declared:
-            print("CAN Socket Already Available. Using: ", CanMotorController.motor_socket)
+        try:
+            self.motor_socket = socket.socket(socket.AF_CAN, socket.SOCK_RAW,
+                                                            socket.CAN_RAW)
+            self.motor_socket.bind(can_socket)
+            self.motor_socket.settimeout(socket_timeout)
+            print("Bound to: ", can_socket)
+        except Exception as e:
+            print("Unable to Connect to Socket Specified: ", can_socket)
+            print("Error:", e)
 
         # Initialize the command BitArrays for performance optimization
         self._p_des_BitArray = BitArray(uint=float_to_uint(0, self.motorParams['P_MIN'],
@@ -231,7 +239,7 @@ class CanMotorController():
         can_dlc = len(data)
         can_msg = struct.pack(can_frame_fmt_send, self.motor_id, can_dlc, data)
         try:
-            CanMotorController.motor_socket.send(can_msg)
+            self.motor_socket.send(can_msg)
         except Exception as e:
             print("Unable to Send CAN Frame.")
             print("Error: ", e)
@@ -242,7 +250,7 @@ class CanMotorController():
         """
         try:
             # The motor sends back only 6 bytes.
-            frame, addr = CanMotorController.motor_socket.recvfrom(recvBytes)
+            frame, addr = self.motor_socket.recvfrom(recvBytes)
             can_id, can_dlc, data = struct.unpack(can_frame_fmt_recv, frame)
             return can_id, can_dlc, data[:can_dlc]
         except Exception as e:
@@ -271,6 +279,14 @@ class CanMotorController():
         Sends the disable motor command to the motor.
         """
         try:
+            # Bugfix: To remove the initial kick at motor start.
+            # The current working theory is that the motor "remembers" the last command. And this
+            # causes an initial kick as the motor controller starts. The fix is then to set the 
+            # last command to zero so that this does not happen. For the user, the behavior does
+            # not change as zero command + disable is same as disable.
+            _, _, _ = self.send_rad_command(0, 0, 0, 0, 0)
+
+            # Do the actual disabling after zero command.
             self._send_can_frame(b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFD')
             waitOhneSleep(dt_sleep)
             can_id, can_dlc, motorStatusData = self._recv_can_frame()
